<?php

namespace Superrobota\Point\Policies;

use Litepie\User\Contracts\UserPolicy;
use Superrobota\Point\Models\Point;

class PointPolicy
{

    /**
     * Determine if the given user can view the point.
     *
     * @param UserPolicy $user
     * @param Point $point
     *
     * @return bool
     */
    public function view(UserPolicy $user, Point $point)
    {
        if ($user->canDo('point.point.view') && $user->isAdmin()) {
            return true;
        }

        return $point->user_id == user_id() && $point->user_type == user_type();
    }

    /**
     * Determine if the given user can create a point.
     *
     * @param UserPolicy $user
     * @param Point $point
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('point.point.create');
    }

    /**
     * Determine if the given user can update the given point.
     *
     * @param UserPolicy $user
     * @param Point $point
     *
     * @return bool
     */
    public function update(UserPolicy $user, Point $point)
    {
        if ($user->canDo('point.point.edit') && $user->isAdmin()) {
            return true;
        }

        return $point->user_id == user_id() && $point->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given point.
     *
     * @param UserPolicy $user
     * @param Point $point
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Point $point)
    {
        return $point->user_id == user_id() && $point->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given point.
     *
     * @param UserPolicy $user
     * @param Point $point
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Point $point)
    {
        if ($user->canDo('point.point.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given point.
     *
     * @param UserPolicy $user
     * @param Point $point
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Point $point)
    {
        if ($user->canDo('point.point.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
